Module action

Module action 

View-to-controller intents.

Every user interaction is represented as an Action and dispatched to the controller.

Enums

Action
EN: UI intents emitted by View and consumed by Controller. RU: Namereniya UI, kotorye otpravlyaet View i obrabatyvaet Controller.