pub struct PlotEditorApp { /* private fields */ }Expand description
EN: Embeddable editor app object for host applications. RU: Vstraivaemy obekt redaktora dlya host-prilozheniy.
Implementations
Sourceimpl PlotEditorApp
impl PlotEditorApp
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates an editor app with empty data and default plot settings.
Examples found in repository?
examples/host_app.rs (line 52)
44fn main() -> Result<(), eframe::Error> {
45 let source = HostDataSource::demo();
46 let native_options = eframe::NativeOptions::default();
47 eframe::run_native(
48 "Host App + Embedded Plot Redactor",
49 native_options,
50 Box::new(move |cc| {
51 cc.egui_ctx.set_visuals(eframe::egui::Visuals::light());
52 let mut app = PlotEditorApp::new();
53 app.controller_mut()
54 .load_from_data_source(&source)
55 .expect("failed to load host data source");
56 Ok(Box::new(app))
57 }),
58 )
59}More examples
examples/host_app2.rs (line 52)
44fn main() -> Result<(), eframe::Error> {
45 let source = HostDataSource::demo();
46 let native_options = eframe::NativeOptions::default();
47 eframe::run_native(
48 "Host App + Embedded Plot Redactor",
49 native_options,
50 Box::new(move |cc| {
51 cc.egui_ctx.set_visuals(eframe::egui::Visuals::light());
52 let mut app = PlotEditorApp::new();
53 app.controller_mut()
54 .load_from_data_source(&source)
55 .expect("failed to load host data source");
56 Ok(Box::new(app))
57 }),
58 )
59}Sourcepub fn controller_mut(&mut self) -> &mut PlotController
pub fn controller_mut(&mut self) -> &mut PlotController
Gives mutable access to controller for host-application integration.
Examples found in repository?
examples/host_app.rs (line 53)
44fn main() -> Result<(), eframe::Error> {
45 let source = HostDataSource::demo();
46 let native_options = eframe::NativeOptions::default();
47 eframe::run_native(
48 "Host App + Embedded Plot Redactor",
49 native_options,
50 Box::new(move |cc| {
51 cc.egui_ctx.set_visuals(eframe::egui::Visuals::light());
52 let mut app = PlotEditorApp::new();
53 app.controller_mut()
54 .load_from_data_source(&source)
55 .expect("failed to load host data source");
56 Ok(Box::new(app))
57 }),
58 )
59}More examples
examples/host_app2.rs (line 53)
44fn main() -> Result<(), eframe::Error> {
45 let source = HostDataSource::demo();
46 let native_options = eframe::NativeOptions::default();
47 eframe::run_native(
48 "Host App + Embedded Plot Redactor",
49 native_options,
50 Box::new(move |cc| {
51 cc.egui_ctx.set_visuals(eframe::egui::Visuals::light());
52 let mut app = PlotEditorApp::new();
53 app.controller_mut()
54 .load_from_data_source(&source)
55 .expect("failed to load host data source");
56 Ok(Box::new(app))
57 }),
58 )
59}Trait Implementations
Sourceimpl App for PlotEditorApp
impl App for PlotEditorApp
Sourcefn update(&mut self, ctx: &Context, _frame: &mut Frame)
fn update(&mut self, ctx: &Context, _frame: &mut Frame)
Called each time the UI needs repainting, which may be many times per second. Read more
Sourcefn save(&mut self, _storage: &mut dyn Storage)
fn save(&mut self, _storage: &mut dyn Storage)
Called on shutdown, and perhaps at regular intervals. Allows you to save state. Read more
Sourcefn on_exit(&mut self, _gl: Option<&Context>)
fn on_exit(&mut self, _gl: Option<&Context>)
Called once on shutdown, after
Self::save. Read moreSourcefn auto_save_interval(&self) -> Duration
fn auto_save_interval(&self) -> Duration
Time between automatic calls to
Self::saveSourcefn clear_color(&self, _visuals: &Visuals) -> [f32; 4]
fn clear_color(&self, _visuals: &Visuals) -> [f32; 4]
Background color values for the app, e.g. what is sent to
gl.clearColor. Read moreSourcefn persist_egui_memory(&self) -> bool
fn persist_egui_memory(&self) -> bool
Controls whether or not the egui memory (window positions etc) will be
persisted (only if the “persistence” feature is enabled).
Sourcefn raw_input_hook(&mut self, _ctx: &Context, _raw_input: &mut RawInput)
fn raw_input_hook(&mut self, _ctx: &Context, _raw_input: &mut RawInput)
A hook for manipulating or filtering raw input before it is processed by
Self::update. Read moreAuto Trait Implementations
impl Freeze for PlotEditorApp
impl RefUnwindSafe for PlotEditorApp
impl Send for PlotEditorApp
impl Sync for PlotEditorApp
impl Unpin for PlotEditorApp
impl UnsafeUnpin for PlotEditorApp
impl UnwindSafe for PlotEditorApp